#!/bin/bash

. /etc/init.d/functions

PATH_CONF="/opt/fofb/cfg/configuration"

shopt -s expand_aliases
alias log="logger -t \"fofb-fpgainit\""

log "Reading configuration file ${PATH_CONF}"


start() {
    if [ ! -f ${PATH_CONF} ]; then
        log -p user.error "Configuration file not found: ${PATH_CONF}"
        exit 1
    fi
    source ${PATH_CONF}

    if [ -e /lib/firmware/base/${FOFB_APP} ]; then
        log "Found configuration ${FOFB_APP}"
    else
        log -p user.error "Could not establish FOFB application"
        exit 1
    fi

    # Taking the last binary file in the sorted list (higher tag)
    PATH_FPGABIN=$(ls -S /lib/firmware/base/${FOFB_APP}/*.bin | tail -n 1)
    log "Loading FPGA image ${PATH_FPGABIN}"
    fpgautil -b ${PATH_FPGABIN} |& log

    # Reset the FPGA
    log "Reset the FPGA"
    /etc/init.d/fw_plreset.sh |& log

    # Linking the correct MAP file
    PATH_MAP="/opt/fofb/map/app_${FOFB_APP}.mapt"
    log "Linking map file ${PATH_MAP}"
    ln -sf ${PATH_MAP} /opt/fofb/map/app.mapt

    # Applying configuration
    fofb-configurator --config /opt/fofb/cfg/config_register --dmap /opt/fofb/opcua-server/devices.dmap |& log

    # Installing /dev links
    for uio in /sys/class/uio/*
    do
        name=$(cat ${uio}/name)
        uiobn=$(basename $uio)
        case $name in
            axiapp|ddr4)
                log "Installing link /dev/$name -> /dev/$uiobn"
                ln -sf /dev/$uiobn /dev/$name
                ;;
            *)
                ;;
        esac
    done

}

stop() {
    log "Nothing to be done"
}



### main logic ###
case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    status)
        echo "Cannot give any status"
        ;;
    restart|reload|condrestart)
        stop
        start
        ;;
    *)
        echo $"Usage: $0 {start|stop|restart|reload|status}"
        exit 1
esac



exit 0
